@@ -74,11 +74,14 @@ enum PIRMakeName{
   Logitech_Make,
   Magnavox_Make,
   Magnum_Make,
+  Medialink_Make,
   Medion_Make,
   Microsoft_Make,
   Mitsubishi_Make,
   Motorola_Make,
+  Multichoice_Make,
   NAD_Make,
+  NEC_Make,
   Nikon_Make,
   Nokia_Make,
   Octagon_Make,
